@@ -187,7 +187,7 @@ class LearnRegressionError:
             # Populating Metric Scores for Validation Error Model
             self.algorithm_performance_df.loc[key, 'Error Model Validation MAE'] = mean_absolute_error(self.validation['Current Model Error'], model_predictions_validation)
             self.algorithm_performance_df.loc[key, 'Error Model Validation RMSE'] = self.np.sqrt(mean_squared_error(self.validation['Current Model Error'],model_predictions_validation))
-            if any(model_predictions_validation < 0):
+            if (model_predictions_validation < 0).any() or (self.validation['Current Model Error'] < 0).any():
                 pass
             else:
                 self.algorithm_performance_df.loc[key, 'Error Model Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation['Current Model Error'],model_predictions_validation))
@@ -198,7 +198,7 @@ class LearnRegressionError:
                 self.test['Current Model Error'], model_predictions_test)
             self.algorithm_performance_df.loc[key, 'Error Model Test RMSE'] = self.np.sqrt(
                 mean_squared_error(self.test['Current Model Error'], model_predictions_test))
-            if any(model_predictions_validation < 0):
+            if (model_predictions_validation < 0).any() or (self.test['Current Model Error'] < 0).any():
                 pass
             else:
                 self.algorithm_performance_df.loc[key, 'Error Model Test RMSLE'] = self.np.sqrt(
@@ -215,7 +215,7 @@ class LearnRegressionError:
                 self.validation[self.output_label], final_output_validation)
             self.algorithm_performance_df.loc[key, 'Final Output Validation RMSE'] = self.np.sqrt(
                 mean_squared_error(self.validation[self.output_label], final_output_validation))
-            if any(final_output_validation < 0):
+            if (final_output_validation < 0).any() or (self.validation[self.output_label] < 0).any():
                 pass
             else:
                 self.algorithm_performance_df.loc[key, 'Final Output Validation RMSLE'] = self.np.sqrt(
@@ -231,7 +231,7 @@ class LearnRegressionError:
                 self.test[self.output_label], final_output_test)
             self.algorithm_performance_df.loc[key, 'Final Output Test RMSE'] = self.np.sqrt(
                 mean_squared_error(self.test[self.output_label], final_output_test))
-            if any(final_output_test < 0):
+            if (final_output_test < 0).any() or (self.test[self.output_label] < 0).any():
                 pass
             else:
                 self.algorithm_performance_df.loc[key, 'Final Output Test RMSLE'] = self.np.sqrt(
@@ -681,12 +681,12 @@ class LearnClassificationError:
         # Sorting Dataframe as per selected evaluation metric
         if self.focus_metric == 'precision':
             self.algorithm_performance_df.sort_values(by='Final Output Validation Precision', inplace=True,
-                                                      ascending=True)
+                                                      ascending=False)
         elif self.focus_metric == 'recall':
-            self.algorithm_performance_df.sort_values(by='Final Output Validation Recall', inplace=True, ascending=True)
+            self.algorithm_performance_df.sort_values(by='Final Output Validation Recall', inplace=True, ascending=False)
         elif self.focus_metric == 'f1-score':
             self.algorithm_performance_df.sort_values(by='Final Output Validation F1-Score', inplace=True,
-                                                      ascending=True)
+                                                      ascending=False)
         else:
             self.algorithm_performance_df.sort_values(by='Final Output Validation Accuracy', inplace=True,
                                                       ascending=False)
@@ -752,10 +752,6 @@ class ProductionPredictionGeneration:
     # Importing important libraries
     np = __import__('numpy')
     pd = __import__('pandas')
-    sklearn = __import__('sklearn')
-    xgb = __import__('xgboost')
-    lgbm = __import__('lightgbm')
-    cat = __import__('catboost')
 
     # Class Constructor
     def __init__(self):
@@ -947,7 +943,7 @@ class ProductionPredictionGeneration:
                 else:
                     column = int(column) - 1
                 final_prediction_set.loc[final_prediction_set[
-                                             'Error Model Predictions'] == unique, self.output_label + ' Predictions'] = column
+                                             'Error Model Predictions'] == unique, output_label + ' Predictions'] = column
 
         final_prediction_set[output_label + ' Predictions'] = final_prediction_set[
             output_label + ' Predictions'].astype(data_type)
